# ScratchEncoder

## Installation

```bash
pip install ScratchEncoder
```

## Usage

```python
encoder = ScratchEncoder.Encoder()
```

Initializes a new encoder object.

## Encoding

```python
encoder.encode('Text')
# Encodes text and returns the encoded value
encoder.decode('value')
# Decodes a value and returns the decoded text
```

## Scratch

View the project on scratch [here](https://scratch.mit.edu/projects/546443308)
Contact me on my [Scratch Profile](https://scratch.mit.edu/users/TheCloudDev/#comments)
